@@ -4,9 +4,6 @@ use r2d2_postgres::PostgresConnectionManager;
 use r2d2::{Pool, PooledConnection};
 use parking_lot::{ RwLock};
 use std::time::Duration;
-use serde::{Serialize};
-use std::fmt::{Display, Formatter, Result as FmtResult};
-use serde_json::{to_string_pretty};
 
 lazy_static!{
 
@@ -75,29 +72,3 @@ fn get_data_source() -> String{
     );
     data_source
 }
-
-
-#[derive(Debug, Serialize)]
-pub enum PgDaoError {
-
-    ConnectionError(String),
-
-    ExecutionError(String),
-
-    TransactionCreationError(String),
-
-    CommitError(String),
-
-    RowError(String),
-
-    Error(String),
-
-}
-
-impl Display for PgDaoError {
-    fn fmt(&self, f: &mut Formatter) -> FmtResult {
-        let error = to_string_pretty(self).unwrap();
-        error!("{}", &error);
-        write!(f, "{}", error)
-    }
-}
