@@ -1,11 +1,11 @@
 use std::{ io};
 use std::fs;
 use std::collections::HashMap;
-use crate::{Value, ColumnType};
 use regex::Regex;
 use std::path::Path;
 use std::fs::File;
 use std::io::BufRead;
+use crate::model::{ColumnType, Value};
 
 pub fn read_lines<P>(filename: P) -> io::Result<io::Lines<io::BufReader<File>>>
     where P: AsRef<Path>, {
